==> jc-1.4.0.tar.gz: soot/grimp/AbstractGrimpValueSwitch.h <==
// public abstract class soot.grimp.AbstractGrimpValueSwitch

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 4ecfaa3a7ae14cd1 soot_grimp_AbstractGrimpValueSwitch
// @dep_class 284aff14bea3930f soot_jimple_AbstractJimpleValueSwitch

// header file dependencies
// @dep_header soot_jimple_AbstractJimpleValueSwitch

#include "soot/jimple/AbstractJimpleValueSwitch.h"

#ifndef _JC_soot_grimp_AbstractGrimpValueSwitch_H_
#define _JC_soot_grimp_AbstractGrimpValueSwitch_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_soot_grimp_NewInvokeExpr$object;

// Typedefs
typedef struct _jc_soot_grimp_AbstractGrimpValueSwitch$sub_refs	_jc_soot_grimp_AbstractGrimpValueSwitch$sub_refs;
typedef struct _jc_soot_grimp_AbstractGrimpValueSwitch$sub_nonrefs	_jc_soot_grimp_AbstractGrimpValueSwitch$sub_nonrefs;
typedef struct _jc_soot_grimp_AbstractGrimpValueSwitch$refs	_jc_soot_grimp_AbstractGrimpValueSwitch$refs;
typedef struct _jc_soot_grimp_AbstractGrimpValueSwitch$nonrefs	_jc_soot_grimp_AbstractGrimpValueSwitch$nonrefs;
typedef struct _jc_soot_grimp_AbstractGrimpValueSwitch$object	_jc_soot_grimp_AbstractGrimpValueSwitch$object;

typedef const struct _jc_soot_grimp_AbstractGrimpValueSwitch$vmethods	_jc_soot_grimp_AbstractGrimpValueSwitch$vmethods;
typedef const struct _jc_soot_grimp_AbstractGrimpValueSwitch$vtable	_jc_soot_grimp_AbstractGrimpValueSwitch$vtable;
typedef const struct _jc_soot_grimp_AbstractGrimpValueSwitch$vtype	_jc_soot_grimp_AbstractGrimpValueSwitch$vtype;

// Constructors
extern void _jc_soot_grimp_AbstractGrimpValueSwitch$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_grimp_AbstractGrimpValueSwitch$object *);

// Virtual methods
extern void _jc_soot_grimp_AbstractGrimpValueSwitch$method$caseNewInvokeExpr$d2257fbd4cc811f6(_jc_env *, struct _jc_soot_grimp_AbstractGrimpValueSwitch$object *, struct _jc_object *);

// Virtual method descriptors
extern _jc_method _jc_soot_grimp_AbstractGrimpValueSwitch$method_info$caseNewInvokeExpr$d2257fbd4cc811f6;

// Virtual methods structure
struct _jc_soot_grimp_AbstractGrimpValueSwitch$vmethods {
	void	(*caseNewInvokeExpr$d2257fbd4cc811f6)(_jc_env *, struct _jc_soot_grimp_AbstractGrimpValueSwitch$object *, struct _jc_object *);
};

// Vtable
struct _jc_soot_grimp_AbstractGrimpValueSwitch$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_AbstractJimpleValueSwitch$vmethods	soot_jimple_AbstractJimpleValueSwitch;
	_jc_soot_grimp_AbstractGrimpValueSwitch$vmethods	soot_grimp_AbstractGrimpValueSwitch;
};

// Vtype
struct _jc_soot_grimp_AbstractGrimpValueSwitch$vtype {
	_jc_type			type;
	_jc_soot_grimp_AbstractGrimpValueSwitch$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_grimp_AbstractGrimpValueSwitch$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_grimp_AbstractGrimpValueSwitch$refs {
    _jc_soot_grimp_AbstractGrimpValueSwitch$sub_refs	soot_grimp_AbstractGrimpValueSwitch;
    _jc_soot_jimple_AbstractJimpleValueSwitch$sub_refs	soot_jimple_AbstractJimpleValueSwitch;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_grimp_AbstractGrimpValueSwitch$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_grimp_AbstractGrimpValueSwitch$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_AbstractJimpleValueSwitch$sub_nonrefs	soot_jimple_AbstractJimpleValueSwitch;
    _jc_soot_grimp_AbstractGrimpValueSwitch$sub_nonrefs	soot_grimp_AbstractGrimpValueSwitch;
};

// Object instance structure
struct _jc_soot_grimp_AbstractGrimpValueSwitch$object {
	_jc_soot_grimp_AbstractGrimpValueSwitch$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_grimp_AbstractGrimpValueSwitch$vtype	*vtype;
	_jc_soot_grimp_AbstractGrimpValueSwitch$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_grimp_AbstractGrimpValueSwitch$vtype _jc_soot_grimp_AbstractGrimpValueSwitch$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_grimp_AbstractGrimpValueSwitch, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_grimp_AbstractGrimpValueSwitch$class_object;

#endif	/* _JC_soot_grimp_AbstractGrimpValueSwitch_H_ */

==> jc-1.4.6.tar.gz: soot/grimp/AbstractGrimpValueSwitch.h <==
// public abstract class soot.grimp.AbstractGrimpValueSwitch

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 4ecfaa3a7ae14cd1 soot_grimp_AbstractGrimpValueSwitch
// @dep_class 284aff14bea3930f soot_jimple_AbstractJimpleValueSwitch

// header file dependencies
// @dep_header soot_jimple_AbstractJimpleValueSwitch

#include "soot/jimple/AbstractJimpleValueSwitch.h"

#ifndef _JC_soot_grimp_AbstractGrimpValueSwitch_H_
#define _JC_soot_grimp_AbstractGrimpValueSwitch_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_soot_grimp_NewInvokeExpr$object;

// Typedefs
typedef struct _jc_soot_grimp_AbstractGrimpValueSwitch$sub_refs	_jc_soot_grimp_AbstractGrimpValueSwitch$sub_refs;
typedef struct _jc_soot_grimp_AbstractGrimpValueSwitch$sub_nonrefs	_jc_soot_grimp_AbstractGrimpValueSwitch$sub_nonrefs;
typedef struct _jc_soot_grimp_AbstractGrimpValueSwitch$refs	_jc_soot_grimp_AbstractGrimpValueSwitch$refs;
typedef struct _jc_soot_grimp_AbstractGrimpValueSwitch$nonrefs	_jc_soot_grimp_AbstractGrimpValueSwitch$nonrefs;
typedef struct _jc_soot_grimp_AbstractGrimpValueSwitch$object	_jc_soot_grimp_AbstractGrimpValueSwitch$object;

typedef const struct _jc_soot_grimp_AbstractGrimpValueSwitch$vmethods	_jc_soot_grimp_AbstractGrimpValueSwitch$vmethods;
typedef const struct _jc_soot_grimp_AbstractGrimpValueSwitch$vtable	_jc_soot_grimp_AbstractGrimpValueSwitch$vtable;
typedef const struct _jc_soot_grimp_AbstractGrimpValueSwitch$vtype	_jc_soot_grimp_AbstractGrimpValueSwitch$vtype;

// Constructors
extern void _jc_soot_grimp_AbstractGrimpValueSwitch$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_grimp_AbstractGrimpValueSwitch$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_soot_grimp_AbstractGrimpValueSwitch$method$caseNewInvokeExpr$d2257fbd4cc811f6(_jc_env *, struct _jc_soot_grimp_AbstractGrimpValueSwitch$object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_grimp_AbstractGrimpValueSwitch$method_info$caseNewInvokeExpr$d2257fbd4cc811f6;

// Virtual methods structure
struct _jc_soot_grimp_AbstractGrimpValueSwitch$vmethods {
	void	(*caseNewInvokeExpr$d2257fbd4cc811f6)(_jc_env *, struct _jc_soot_grimp_AbstractGrimpValueSwitch$object *, struct _jc_object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_grimp_AbstractGrimpValueSwitch$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_AbstractJimpleValueSwitch$vmethods	soot_jimple_AbstractJimpleValueSwitch;
	_jc_soot_grimp_AbstractGrimpValueSwitch$vmethods	soot_grimp_AbstractGrimpValueSwitch;
};

// Vtype
struct _jc_soot_grimp_AbstractGrimpValueSwitch$vtype {
	_jc_type			type;
	_jc_soot_grimp_AbstractGrimpValueSwitch$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_grimp_AbstractGrimpValueSwitch$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_grimp_AbstractGrimpValueSwitch$refs {
    _jc_soot_grimp_AbstractGrimpValueSwitch$sub_refs	soot_grimp_AbstractGrimpValueSwitch;
    _jc_soot_jimple_AbstractJimpleValueSwitch$sub_refs	soot_jimple_AbstractJimpleValueSwitch;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_grimp_AbstractGrimpValueSwitch$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_grimp_AbstractGrimpValueSwitch$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_AbstractJimpleValueSwitch$sub_nonrefs	soot_jimple_AbstractJimpleValueSwitch;
    _jc_soot_grimp_AbstractGrimpValueSwitch$sub_nonrefs	soot_grimp_AbstractGrimpValueSwitch;
};

// Object instance structure
struct _jc_soot_grimp_AbstractGrimpValueSwitch$object {
	_jc_soot_grimp_AbstractGrimpValueSwitch$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_grimp_AbstractGrimpValueSwitch$vtype	*vtype;
	_jc_soot_grimp_AbstractGrimpValueSwitch$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_grimp_AbstractGrimpValueSwitch$vtype _jc_soot_grimp_AbstractGrimpValueSwitch$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_grimp_AbstractGrimpValueSwitch, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_grimp_AbstractGrimpValueSwitch$class_object;

#endif	/* _JC_soot_grimp_AbstractGrimpValueSwitch_H_ */
